NAME
Authen::RBAC - Perl extension to manage Authen::RBAC configs
SYNOPSIS
use Authen::RBAC;
DESCRIPTION
This perl module manages manages Authen::RBAC XML configs and authorize against them
INTERFACE
The following methods are available in this module.
new(debug=>$debug);
parse_xml_file($xmlfile)
Parse XML config file
parse_xml_dir($xmldir)
Parse XML config file(s)
output_xml($group)
Output XML config file for a specific group
get_loaded_groups()
Returns a reference to an array containing the names of currently loaded groups
get_acls_in_group($group)
Returns a reference to an array of acl names in a group
get_policies_in_acl($group,$acl)
Returns a reference to an array of policies in a specific acl
delete_group($group)
Removes a group
add_group($group)
Add new group
add_acl_to_group($group_name, $acl_name, $default_policy)
Add a new ACL to a group
delete_acl_from_group($group_name, $acl_name)
Delete an ACL from a group
add_policy_to_acl($group_name, $acl_name, $policy_type, $base_pattern, \@additional_patterns)
Add a new policy to ACL
delete_policy_from_acl($group_name, $acl_name, $policy_type, $base_pattern, \@add_patterns)
Delete a policy from an acl
authorize(user,command,hostname)
Checks whether a user is allowed to execute a command on a specific device
Accepts a scalar user name, scalar command, and a scalar hostname
Returns 1 for success
Returns undef for failure
debug()
Set the module debug level
_preload_unix_groups
Determines unix group memberships for all users
_parse(\@xmlconfs)
Parses the current Authen::RBAC XML configuration file
Returns reference to a hash containing the config file name and "1" for success and undef for failure Returns undef for failure
AUTHOR
Dennis Opacki, dopacki@adotout.com
SEE ALSO
perl(1).